@@ -1,3 +1,6 @@
+from .. import db
+db = db.db
+
 from . import fire
 from . import sls
 from . import uls
@@ -5,12 +8,9 @@ from . import uls
 from .sls.longterm import cemprops
 from .sls.longterm import creep_coef
 from .sls.longterm import shrink_strain
-# from .uls.shear import *
-# from .uls.bend_simple import *
 
 from .uls.shear import shear_asws
 from .uls.shear import shear_vrd
 from .uls.shear import shear_vrdc
 from .uls.bend_simple import bend_params
-# from .ec2_crack import *
-# from .ec2_deformation import *
\ No newline at end of file
+from .uls.shell_reinforcement import as_shell
