@@ -1,8 +1,16 @@
+from .. import db
+db = db
+
 from .shear import shear_asws
 from .shear import shear_vrd
 from .shear import shear_vrdc
 
 from .bend_simple import bend_params
 
+from .shell_reinforcement import as_shell
+
 from . import shear
 from . import bend_simple
+from . import shell_reinforcement
+
+
